@@ -23,7 +23,6 @@
 
 #include "qgis_core.h"
 #include "qgis_sip.h"
-#include "qgis.h"
 #include <memory>
 #include <QHash>
 #include <QList>
@@ -47,6 +46,7 @@
 #include "qgstranslationcontext.h"
 #include "qgsprojecttranslator.h"
 #include "qgsattributeeditorelement.h"
+#include "qgscolorscheme.h"
 
 class QFileInfo;
 class QDomDocument;
@@ -690,6 +690,9 @@ class CORE_EXPORT QgsProject : public QObject, public QgsExpressionContextGenera
     //! Returns the number of registered layers.
     int count() const;
 
+    //! Returns the number of registered valid layers.
+    int validCount() const;
+
     /**
      * Retrieve a pointer to a registered layer by layer ID.
      * \param layerId ID of layer to retrieve
@@ -699,6 +702,30 @@ class CORE_EXPORT QgsProject : public QObject, public QgsExpressionContextGenera
      */
     QgsMapLayer *mapLayer( const QString &layerId ) const;
 
+#ifndef SIP_RUN
+
+    /**
+     * Retrieve a pointer to a registered layer by \p layerId converted
+     * to type T. This is a convenience template.
+     * A nullptr will be returned if the layer is not found or
+     * if it cannot be cast to type T.
+     *
+     * \code{cpp}
+     * QgsVectorLayer *layer = project->mapLayer<QgsVectorLayer*>( layerId );
+     * \endcode
+     *
+     * \see mapLayer()
+     * \see mapLayers()
+     *
+     * \since QGIS 3.6
+     */
+    template <class T>
+    T mapLayer( const QString &layerId ) const
+    {
+      return qobject_cast<T>( mapLayer( layerId ) );
+    }
+#endif
+
     /**
      * Retrieve a list of matching registered layers by layer name.
      * \param layerName name of layers to match
@@ -710,11 +737,13 @@ class CORE_EXPORT QgsProject : public QObject, public QgsExpressionContextGenera
 
     /**
      * Returns a map of all registered layers by layer ID.
+     *
+     * \param validOnly if set only valid layers will be returned
      * \see mapLayer()
      * \see mapLayersByName()
      * \see layers()
      */
-    QMap<QString, QgsMapLayer *> mapLayers() const;
+    QMap<QString, QgsMapLayer *> mapLayers( const bool validOnly = false ) const;
 
     /**
      * Returns true if the project comes from a zip archive, false otherwise.
@@ -757,7 +786,7 @@ class CORE_EXPORT QgsProject : public QObject, public QgsExpressionContextGenera
      *                      the layers yourself. Not available in Python.
      *
      * \returns a list of the map layers that were added
-     *         successfully. If a layer is invalid, or already exists in the registry,
+     *         successfully. If a layer or already exists in the registry,
      *         it will not be part of the returned QList.
      *
      * \note As a side-effect QgsProject is made dirty.
@@ -817,6 +846,8 @@ class CORE_EXPORT QgsProject : public QObject, public QgsExpressionContextGenera
      */
     void removeMapLayers( const QStringList &layerIds );
 
+    //TODO QGIS 4.0 - add PyName alias to avoid list type conversion error
+
     /**
      * \brief
      * Remove a set of layers from the registry.
@@ -830,7 +861,6 @@ class CORE_EXPORT QgsProject : public QObject, public QgsExpressionContextGenera
      * \see removeMapLayer()
      * \see removeAllMapLayers()
      */
-    //TODO QGIS 3.0 - add PyName alias to avoid list type conversion error
     void removeMapLayers( const QList<QgsMapLayer *> &layers );
 
     /**
@@ -972,6 +1002,14 @@ class CORE_EXPORT QgsProject : public QObject, public QgsExpressionContextGenera
      */
     Q_DECL_DEPRECATED void setRequiredLayers( const QSet<QgsMapLayer *> &layers );
 
+    /**
+     * Sets the \a colors for the project's color scheme (see QgsProjectColorScheme).
+     *
+     * \see projectColorsChanged()
+     * \since QGIS 3.6
+     */
+    void setProjectColors( const QgsNamedColorList &colors );
+
     /**
      * Triggers the collection strings of .qgs to be included in ts file and calls writeTsFile()
      * \since QGIS 3.4
@@ -1172,6 +1210,14 @@ class CORE_EXPORT QgsProject : public QObject, public QgsExpressionContextGenera
      */
     void metadataChanged();
 
+    /**
+     * Emitted whenever the project's color scheme has been changed.
+
+     * \see setProjectColors()
+     * \since QGIS 3.6
+     */
+    void projectColorsChanged();
+
     //
     // signals from QgsMapLayerRegistry
     //
@@ -1234,13 +1280,14 @@ class CORE_EXPORT QgsProject : public QObject, public QgsExpressionContextGenera
      */
     void layerRemoved( const QString &layerId );
 
+    //TODO QGIS 4.0 - rename to past tense
+
     /**
      * Emitted when all layers are removed, before layersWillBeRemoved() and
      * layerWillBeRemoved() signals are emitted. The layersWillBeRemoved() and
      * layerWillBeRemoved() signals will still be emitted following this signal.
      * You can use this signal to do easy (and fast) cleanup.
      */
-    //TODO QGIS 3.0 - rename to past tense
     void removeAll();
 
     /**
@@ -1456,6 +1503,8 @@ class CORE_EXPORT QgsProject : public QObject, public QgsExpressionContextGenera
 
     std::unique_ptr< QTranslator > mTranslator;
 
+    bool mIsBeingDeleted = false;
+
     friend class QgsProjectDirtyBlocker;
 
     // Required by QGIS Server for switching the current project instance
