@@ -23,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
 from qgis.core import (QgsProcessing,
                        QgsProcessingParameterFeatureSource,
@@ -189,7 +189,15 @@ class Ogr2OgrToPostGisList(GdalAlgorithm):
         return 'importvectorintopostgisdatabaseavailableconnections'
 
     def displayName(self):
-        return self.tr('Import vector into PostGIS database (available connections)')
+        return self.tr('Export to PostgreSQL (available connections)')
+
+    def shortDescription(self):
+        return self.tr('Exports a vector layer to an existing PostgreSQL database connection')
+
+    def tags(self):
+        t = self.tr('import,into,postgis,database,vector').split(',')
+        t.extend(super().tags())
+        return t
 
     def group(self):
         return self.tr('Vector miscellaneous')
@@ -269,9 +277,9 @@ class Ogr2OgrToPostGisList(GdalAlgorithm):
             arguments.append(self.GEOMTYPE[self.parameterAsEnum(parameters, self.GTYPE, context)])
         if len(geocolumn) > 0:
             arguments.append(geocolumnstring)
-        if len(pk) > 0:
+        if pk:
             arguments.append(pkstring)
-        elif primary_key is not None:
+        elif primary_key:
             arguments.append("-lco FID=" + primary_key)
         if len(table) == 0:
             table = layername.lower()
