@@ -23,7 +23,7 @@ __copyright__ = '(C) 2015, Médéric Ribreux'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'f6ddc62fdb8ae589d3827e84d0c25bf669931040'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
 
 import os
@@ -48,20 +48,20 @@ def processCommand(alg, parameters, context, feedback):
     threshold = alg.parameterAsDouble(parameters, 'threshold', context)
 
     # Create the v.net connect command for from_layer integration
-    command = u"v.net input={} points={} output={} operation=connect threshold={} arc_layer=1 node_layer=2".format(
+    command = 'v.net -s input={} points={} output={} operation=connect threshold={} arc_layer=1 node_layer=2'.format(
         lineLayer, fromLayer, intLayer, threshold)
     alg.commands.append(command)
 
     # Do it again with to_layer
-    command = u"v.net input={} points={} output={} operation=connect threshold={} arc_layer=1 node_layer=3".format(
+    command = 'v.net -s input={} points={} output={} operation=connect threshold={} arc_layer=1 node_layer=3'.format(
         intLayer, toLayer, netLayer, threshold)
     alg.commands.append(command)
 
     # Connect the point layer database to the layer 2 of the network
-    command = u"v.db.connect -o map={} table={} layer=2".format(netLayer, fromLayer)
+    command = 'v.db.connect -o map={} table={} layer=2'.format(netLayer, fromLayer)
     alg.commands.append(command)
 
-    command = u"v.db.connect -o map={} table={} layer=3".format(netLayer, toLayer)
+    command = 'v.db.connect -o map={} table={} layer=3'.format(netLayer, toLayer)
     alg.commands.append(command)
 
     # remove undesired parameters
