@@ -23,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '1edf372fb80f2a35c77b128dc143c0f3c97cd8f3'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
 import os
 import math
@@ -66,7 +66,7 @@ class CreateConstantRaster(QgisAlgorithm):
         self.addParameter(QgsProcessingParameterNumber(self.PIXEL_SIZE,
                                                        self.tr('Pixel size'),
                                                        QgsProcessingParameterNumber.Double,
-                                                       0.1, False, 0.01, 999))
+                                                       0.1, False, 0.01))
         self.addParameter(QgsProcessingParameterNumber(self.NUMBER,
                                                        self.tr('Constant value'),
                                                        QgsProcessingParameterNumber.Double,
