@@ -23,7 +23,7 @@ __copyright__ = '(C) 2014, Alexander Bruy'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '58734527abdbaab95719a48a4a64ea05abd70b44'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
 import os
 import random
@@ -112,7 +112,7 @@ class RandomPointsLayer(QgisAlgorithm):
         fields.append(QgsField('id', QVariant.Int, '', 10, 0))
 
         (sink, dest_id) = self.parameterAsSink(parameters, self.OUTPUT, context,
-                                               fields, QgsWkbTypes.Point, source.sourceCrs())
+                                               fields, QgsWkbTypes.Point, source.sourceCrs(), QgsFeatureSink.RegeneratePrimaryKey)
         if sink is None:
             raise QgsProcessingException(self.invalidSinkError(parameters, self.OUTPUT))
 
