@@ -23,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
 
 class AlgorithmDialogBase:
@@ -32,3 +32,9 @@ class AlgorithmDialogBase:
 
         def __init__(self, param, widget):
             (self.parameter, self.widget) = (param, widget)
+
+    class InvalidOutputExtension(Exception):
+
+        def __init__(self, widget, message):
+            self.widget = widget
+            self.message = message
