@@ -23,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '2f64a3c4e74022c5555ee19862f034ffacc2b5fe'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
 import os
 
@@ -39,6 +39,7 @@ from qgis.core import (Qgis,
 
 from processing.core.ProcessingConfig import ProcessingConfig, Setting
 
+from processing.gui.ContextAction import ContextAction
 from processing.gui.ProviderActions import (ProviderActions,
                                             ProviderContextMenuActions)
 
@@ -46,6 +47,7 @@ from processing.modeler.AddModelFromFileAction import AddModelFromFileAction
 from processing.modeler.CreateNewModelAction import CreateNewModelAction
 from processing.modeler.DeleteModelAction import DeleteModelAction
 from processing.modeler.EditModelAction import EditModelAction
+from processing.modeler.ExportModelAsPythonScriptAction import ExportModelAsPythonScriptAction
 from processing.modeler.OpenModelFromFileAction import OpenModelFromFileAction
 from processing.modeler.exceptions import WrongModelException
 from processing.modeler.ModelerUtils import ModelerUtils
@@ -58,7 +60,9 @@ class ModelerAlgorithmProvider(QgsProcessingProvider):
     def __init__(self):
         super().__init__()
         self.actions = [CreateNewModelAction(), OpenModelFromFileAction(), AddModelFromFileAction()]
-        self.contextMenuActions = [EditModelAction(), DeleteModelAction()]
+        sep_action = ContextAction()
+        sep_action.is_separator = True
+        self.contextMenuActions = [EditModelAction(), DeleteModelAction(), sep_action, ExportModelAsPythonScriptAction()]
         self.algs = []
         self.isLoading = False
 
